==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/admin/messages/fa-IR/information.php <==
<?php

return [
    'About HumHub' => 'درباره هام‌هاب',
    'Base URL' => 'آدرس پایه',
    'Checking HumHub software prerequisites.' => 'چک کردن پیش‌نیازهای نرم‌افزار هام‌هاب',
    'Database' => 'پایگاه داده',
    'Database migration results:' => 'نتایج مهاجرت پایگاه داده:',
    'Delayed' => 'تاخیر خورده',
    'Displaying {count} entries per page.' => 'نمایش {count} مطالب برای هر صفحه',
    'Done' => 'انجام شد',
    'Driver' => 'راه‌انداز',
    'Error' => 'خطا',
    'Flush entries' => 'تخلیه‌ی مطالب',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'هام‌هاب هم اکنون در حالت خطایابی (debug) است.',
    'Last run (daily):' => 'آخرین اجرا (روزانه):',
    'Last run (hourly):' => 'آخرین اجرا (ساعت):',
    'Licences' => 'گواهینامه‌ها',
    'Logging' => 'ثبت رویدادها',
    'Never' => 'هرگز',
    'Other' => 'ديگر',
    'Permissions' => 'مجوزها',
    'Prerequisites' => 'پیش‌نیازها',
    'Re-Run tests' => 'باز-اجرای آزمون‌ها',
    'See installation manual for more details.' => 'راهنمای نصب را برای جزئیات بیشتر ببینید',
    'Select category..' => 'دسته را برگزینید...',
    'Select day' => 'روز را برگزینید',
    'Select level...' => 'سطح را برگزینید...',
    'Settings' => 'تنطیمات',
    'There is a new update available! (Latest version: %version%)' => 'یک به‌روزرسانی تازه موجود است! (آخرین نسخه: %version%)',
    'This HumHub installation is up to date!' => 'هام‌هاب نصب شده به‌روز است!',
    'Total {count} entries found.' => '{count} مدخل یافت شد.',
    'Waiting' => 'در انتظار',
    'Warning' => 'اخطار',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    '<strong>CronJob</strong> Status' => '',
    '<strong>Queue</strong> Status' => '',
    'Assets' => '',
    'Background Jobs' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Queue successfully cleared.' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Reserved' => '',
    'Runtime' => '',
    'Search index rebuild in progress.' => '',
    'Search term...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The current main HumHub database name is ' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/fa-IR/information.php <==
<?php

return [
    'About HumHub' => 'درباره هام‌هاب',
    'Base URL' => 'آدرس پایه',
    'Checking HumHub software prerequisites.' => 'چک کردن پیش‌نیازهای نرم‌افزار هام‌هاب',
    'Database' => 'پایگاه داده',
    'Database migration results:' => 'نتایج مهاجرت پایگاه داده:',
    'Delayed' => 'تاخیر خورده',
    'Displaying {count} entries per page.' => 'نمایش {count} مطالب برای هر صفحه',
    'Done' => 'انجام شد',
    'Driver' => 'راه‌انداز',
    'Error' => 'خطا',
    'Flush entries' => 'تخلیه‌ی مطالب',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'هام‌هاب هم اکنون در حالت خطایابی (debug) است.',
    'Last run (daily):' => 'آخرین اجرا (روزانه):',
    'Last run (hourly):' => 'آخرین اجرا (ساعت):',
    'Licences' => 'گواهینامه‌ها',
    'Logging' => 'ثبت رویدادها',
    'Never' => 'هرگز',
    'Other' => 'ديگر',
    'Permissions' => 'مجوزها',
    'Prerequisites' => 'پیش‌نیازها',
    'Re-Run tests' => 'باز-اجرای آزمون‌ها',
    'See installation manual for more details.' => 'راهنمای نصب را برای جزئیات بیشتر ببینید',
    'Select category..' => 'دسته را برگزینید...',
    'Select day' => 'روز را برگزینید',
    'Select level...' => 'سطح را برگزینید...',
    'Settings' => 'تنطیمات',
    'There is a new update available! (Latest version: %version%)' => 'یک به‌روزرسانی تازه موجود است! (آخرین نسخه: %version%)',
    'This HumHub installation is up to date!' => 'هام‌هاب نصب شده به‌روز است!',
    'Total {count} entries found.' => '{count} مدخل یافت شد.',
    'Waiting' => 'در انتظار',
    'Warning' => 'اخطار',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    '<strong>CronJob</strong> Status' => '',
    '<strong>Queue</strong> Status' => '',
    'Assets' => '',
    'Background Jobs' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Queue successfully cleared.' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Reserved' => '',
    'Runtime' => '',
    'Search index rebuild in progress.' => '',
    'Search term...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The current main HumHub database name is ' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
